library(tidyverse)
library(ggthemes)

# change to local directory here!
ldir <- ""

df_i <- read_tsv(paste0(ldir, "/pwas/ANA_B2_V2_20200701/interval.all.tsv.gz")) %>%
            mutate(panel = PANEL, z = TWAS.Z, p = TWAS.P)

df_l <- read_tsv(paste0(ldir, "/twas/ANA_B2_V2_20200701/gtexv8.lung.all.tsv.gz")) %>%
            mutate(color = palette[gtex_l])
            mutate(panel = PANEL, z = TWAS.Z, p = TWAS.P)

df_b <- read_tsv(paste0(ldir, "/twas/ANA_B2_V2_20200701/gtexv8.whole_blood.all.tsv.gz")) %>%
            mutate(color = palette[gtex_b])
            mutate(panel = PANEL, z = TWAS.Z, p = TWAS.P)

df_sp_l <- read_tsv(paste0(ldir, "/sp_twas/ANA_B2_V2_20200701/gtexv8.lung.all.tsv.gz")) %>%
            mutate(panel = paste0(PANEL, ".Splice"),
                   z = TWAS.Z, p = TWAS.P)

df_sp_l <- read_tsv(paste0(ldir, "/sp_twas/ANA_B2_V2_20200701/gtexv8.whole_blood.all.tsv.gz")) %>%
            mutate(panel = paste0(PANEL, ".Splice"),
                   z = TWAS.Z, p = TWAS.P)

df_all <- bind_rows(list(df_i, df_l, df_b, df_sp_l, df_sp_b)) %>%
            select(panel, z, p)

max_y <- max(-log10(df_all$p) + 1e-3) # add small epsilon to not cutoff

palette <- PNWColors::pnw_palette("Shuksan2", 5)
gtex_l <- 1
gtex_b <- 2
interval <- 3
gtex_sp_l <- 4
gtex_sp_b <- 5

qexp_10 <- function(p, rate = 1, lower.tail = TRUE, log.p = FALSE) qexp(p, rate, lower.tail, log.p) / log(10)

qqplot_all <- ggplot(df_all, aes(sample = -log10(p), color = panel)) +
                geom_abline(slope=1) +
                stat_qq(distribution=qexp_10) +
                theme_hc() +
                ylab(bquote("Observed"~~-log[10](p))) +
                xlab(bquote("Expected"~~-log[10](p))) +
                ylim(c(0, max_y)) +
                xlim(c(0, max_y)) +
                scale_color_manual(name="QTL Reference", 
                                   values=wes_palette("IsleofDogs1"))
cat("all lgc = ", median(df_all$z^2)/.455, "\n")

qqplot_i <- ggplot(df_i, aes(sample = -log10(p), color = panel)) +
                geom_abline(slope=1) +
                stat_qq(distribution=qexp_10) +
                theme_hc() +
                ylab(bquote("Observed"~~-log[10](p))) +
                xlab(bquote("Expected"~~-log[10](p))) +
                ylim(c(0, max_y)) +
                xlim(c(0, max_y)) +
                scale_color_manual(name="QTL Reference",
                                   values=palette[interval]) +
                theme(legend.position="none")
cat("interval lgc = ", median(df_i$z^2)/.455, "\n")

qqplot_l <- ggplot(df_l, aes(sample = -log10(p), color = panel)) +
                geom_abline(slope=1) +
                stat_qq(distribution=qexp_10) +
                theme_hc() +
                ylab(bquote("Observed"~~-log[10](p))) +
                xlab(bquote("Expected"~~-log[10](p))) +
                ylim(c(0, max_y)) +
                xlim(c(0, max_y)) +
                scale_color_manual(name="QTL Reference",
                                   values=palette[gtex_l]) +
                theme(legend.position="none")
cat("gtex lung lgc = ", median(df_l$z^2)/.455, "\n")

qqplot_b <- ggplot(df_b, aes(sample = -log10(p), color = panel)) +
                geom_abline(slope=1) +
                stat_qq(distribution=qexp_10) +
                theme_hc() +
                ylab(bquote("Observed"~~-log[10](p))) +
                xlab(bquote("Expected"~~-log[10](p))) +
                ylim(c(0, max_y)) +
                xlim(c(0, max_y)) +
                scale_color_manual(name="QTL Reference",
                                   values=palette[gtex_b]) +
                theme(legend.position="none")
cat("gtex wb lgc = ", median(df_b$z^2)/.455, "\n")

qqplot_sp_l <- ggplot(df_sp_l, aes(sample = -log10(p), color = panel)) +
                geom_abline(slope=1) +
                stat_qq(distribution=qexp_10) +
                theme_hc() +
                ylab(bquote("Observed"~~-log[10](p))) +
                xlab(bquote("Expected"~~-log[10](p))) +
                ylim(c(0, max_y)) +
                xlim(c(0, max_y)) +
                scale_color_manual(name="QTL Reference",
                                   values=palette[gtex_sp_l]) +
                theme(legend.position="none")
cat("gtex splice l lgc = ", median(df_sp_l$z^2)/.455, "\n")

qqplot_sp_b <- ggplot(df_sp_b, aes(sample = -log10(p), color = panel)) +
                geom_abline(slope=1) +
                stat_qq(distribution=qexp_10) +
                theme_hc() +
                ylab(bquote("Observed"~~-log[10](p))) +
                xlab(bquote("Expected"~~-log[10](p))) +
                ylim(c(0, max_y)) +
                xlim(c(0, max_y)) +
                scale_color_manual(name="QTL Reference",
                                   values=palette[gtex_sp_b]) +
                theme(legend.position="none")
cat("gtex splice b lgc = ", median(df_sp_b$z^2)/.455, "\n")

ggsave("ana_b2.qqplot.all.pdf", plot=qqplot_all, height=3, width=3)
ggsave("ana_b2.qqplot.interval.pdf", plot=qqplot_i, height=3, width=3)
ggsave("ana_b2.qqplot.gtexv8.lung.pdf", plot=qqplot_l, height=3, width=3)
ggsave("ana_b2.qqplot.gtexv8.whole_blood.pdf", plot=qqplot_b, height=3, width=3)
ggsave("ana_b2.qqplot.gtexv8.splice.lung.pdf", plot=qqplot_sp_l, height=3, width=3)
ggsave("ana_b2.qqplot.gtexv8.splice.whole_blood.pdf", plot=qqplot_sp_b, height=3, width=3)

ggsave("ana_b2.qqplot.all.png", plot=qqplot_all, height=3, width=3)
ggsave("ana_b2.qqplot.interval.png", plot=qqplot_i, height=3, width=3)
ggsave("ana_b2.qqplot.gtexv8.lung.png", plot=qqplot_l, height=3, width=3)
ggsave("ana_b2.qqplot.gtexv8.whole_blood.png", plot=qqplot_b, height=3, width=3)
ggsave("ana_b2.qqplot.gtexv8.splice.lung.png", plot=qqplot_sp_l, height=3, width=3)
ggsave("ana_b2.qqplot.gtexv8.splice.whole_blood.png", plot=qqplot_sp_b, height=3, width=3)
